@@ -6,55 +6,56 @@ import typing as tp
 import pandas as pd
 
 from jijbench.node.base import FunctionNode
-from jijbench.typing import DataNodeT, DataNodeT2
+from jijbench.typing import DataNodeInT, DataNodeOutT
 
 if tp.TYPE_CHECKING:
     from jijbench.containers.containers import Artifact, Record, Table
 
 
-class Factory(FunctionNode[DataNodeT, DataNodeT2]):
+class Factory(FunctionNode[DataNodeInT, DataNodeOutT]):
     """An abstract base class for creating a new data node from a list of input nodes.
-
+    
     Attributes:
-        inputs (List[DataNodeT]): List of input data nodes.
-        name (str or None): Name of the resulting data node.
-
+        inputs (list[`DataNodeInT`]): List of input data nodes.
+        name (Optional[str]): Name of the resulting data node.
     """
 
     @abc.abstractmethod
-    def create(self, inputs: list[DataNodeT], name: str | None = None) -> DataNodeT2:
+    def create(
+        self, inputs: list[DataNodeInT], name: str | None = None
+    ) -> DataNodeOutT:
         """Abstract method to create a new data node.
         Subclasses must implement this method.
 
         Args:
-            inputs (List[DataNodeT]): List of input data nodes.
-            name (str or None): Name of the resulting data node.
+            inputs (List[DataNodeInT]): List of input data nodes.
+            name (str | None): Name of the resulting data node.
 
         Returns:
-            DataNodeT2: The resulting data node.
+            DataNodeOutT: The resulting data node.
 
         """
         pass
 
     def operate(
-        self, inputs: list[DataNodeT], name: str | None = None, **kwargs: tp.Any
-    ) -> DataNodeT2:
+        self, inputs: list[DataNodeInT], name: str | None = None, **kwargs: tp.Any
+    ) -> DataNodeOutT:
         """Create a new data node from the given inputs.
         This method calls `create` method to create a new data node from the given inputs.
 
         Args:
-            inputs (List[DataNodeT]): List of input data nodes.
-            name (str or None, optional): Name of the resulting data node.
+            inputs (list[DataNodeInT]): List of input data nodes.
+            name (str | None, optional): Name of the resulting data node.
             **kwargs: Additional keyword arguments.
 
         Returns:
-            DataNodeT2: The resulting data node.
+            DataNodeOutT: The resulting data node.
 
         """
         return self.create(inputs, name, **kwargs)
 
 
-class RecordFactory(Factory[DataNodeT, "Record"]):
+class RecordFactory(Factory[DataNodeInT, "Record"]):
     """A factory class for creating Record objects.
 
     This class creates Record objects from a list of input DataNode objects. It uses the `create` method to
@@ -65,20 +66,17 @@ class RecordFactory(Factory[DataNodeT, "Record"]):
 
     def create(
         self,
-        inputs: list[DataNodeT],
+        inputs: list[DataNodeInT],
         name: str = "",
     ) -> Record:
         """Create a Record object from the input DataNode objects.
 
         This method takes a list of input DataNode objects, processes them and converts them into a pandas
-        Series. The resulting Series is used to create the Record object. If the input data is a `jijmodeling.SampleSet`
-        and `is_parsed_sampleset` is set to True, the relevant data is extracted from the SampleSet using the
-        `_to_nodes_from_sampleset` helper method.
+        Series. The resulting Series is used to create the Record object.
 
         Args:
-            inputs (list[DataNodeT]): A list of DataNode objects to be processed.
+            inputs (list[DataNodeInT]): A list of DataNode objects to be processed.
             name (str, optional): A name for the Record object. Defaults to "".
-            is_parsed_sampleset (bool, optional): Whether to extract data from jijmodeling SampleSet objects. Defaults to True.
 
         Returns:
             Record: A Record object created from the processed input DataNode objects.
